@@ -17,7 +17,7 @@ def start_jobs(cases: list[str]) -> None:
     """
     Start an analysis for the given cases
     """
-    cases_to_start = check_load_on_cluster(cases=cases)
+    cases_to_start: list[str] = check_load_on_cluster(cases=cases)
     for case in cases_to_start:
         LOG.info("Starting analysis for %s" % case)
 
